@@ -5,6 +5,9 @@ from .constantdescriptors import ConstantDescriptor
 def typesystem(**kwargs):
     """Decorator for imposing typesystem.
 
+    A specific descriptor is associated to class attributes in the
+    argument list.
+
     Examples
     --------
     Simple class decorating.
@@ -12,9 +15,10 @@ def typesystem(**kwargs):
     >>> import joommfutil.typesystem as ts
     >>> @ts.typesystem(a=ts.UnsignedReal)
     ... class A:
-    ...     def __init__(self, a):
+    ...     def __init__(self, a, b):
     ...         self.a = a
- 
+    ...         self.b = b
+    
     """
     def decorate(cls):
         for key, value in kwargs.items():
@@ -23,6 +27,5 @@ def typesystem(**kwargs):
                 setattr(cls, key, value)
             else:
                 setattr(cls, key, value(key))
-
         return cls
     return decorate
